@@ -493,5 +493,10 @@ class K3SRepositoryImpl(K3SRepository, RepositoryImpl):
         namespace_name = namespace_name.get_value()
         pod_name = pod_name.get_value()
         tail_lines = tail_lines.get_value()
-        return self.ao.get_pod_log(cluster_name, namespace_name, pod_name, tail_lines)
+        result = self.ao.get_pod_log(cluster_name, namespace_name, pod_name, tail_lines)
+        if result.succeed and result.get_value() is not None:
+            return result.get_value()
+        else:
+            self.log_func(result.error_traceback)
+            return None
 
